@@ -20,8 +20,10 @@ SERVICES = [
     "jira",
     "heroku",
     "mailgun",
+    "newrelic",
     "npm",
     "nylas",
+    "ownbackup",
     "pagerduty",
     "personio",
     "pypi",
